
# Type: class_uri


URI of the class in an RDF environment

URI: [meta:class_uri](https://w3id.org/biolink/biolinkml/meta/class_uri)


## Domain and Range

[ClassDefinition](ClassDefinition.md) ->  <sub>OPT</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
